@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import numpy as np
 from iqsopenapi import *
+import datetime
 
 def on_init(ctx):
     #variables
@@ -12,7 +13,9 @@ def on_init(ctx):
     ctx.domi_contract = None
     ctx.last_domi = None
 
-    ctx.subscribe(('rb2010.SHFE','1m'),('IH2005.CFFEX','3m'))
+    id = ctx.get_strategy_id()
+
+    ctx.subscribe(('IH2006.CFFEX','2m'),('jd2009.CFFEX','3m'))
 
     ctx.domi_contract = ctx.get_dominant_contract(ctx.symbol)
     conInfo = ctx.get_contract(ctx.domi_contract.symbol)
@@ -35,6 +38,23 @@ def on_init(ctx):
 
     order2 = ctx.get_order(order.order_id)
 
+    bars1 = ctx.get_history_bars('rb2010.SHFE','1m','20200521','20200522')
+
+    bars2 = ctx.get_history_bars('rb2010.SHFE','1m',datetime(2020,5,21,9,10,0),datetime(2020,5,21,11,10,0))
+
+    bars2 = ctx.get_history_bars('rb2010.SHFE','1m',date(2020,5,21),date(2020,5,22))
+    
+    ctx.run_by_time(run_time,datetime(2020,5,21,13,58,0),'CCC','DDDDD')
+
+    #ctx.run_by_time(run_time,time(13,50,0))
+
+    #ctx.insert_func_at_time(run_time,time(13,49,0))
+
+    ctx.insert_func_at_time(run_time,datetime(2020,5,21,13,55,0),'AAA','BBBB')
+
+    pass
+
+def run_time(*args):
     pass
     
 def on_open(ctx):
@@ -107,7 +127,7 @@ def on_bar(ctx,bar):
     #    ctx.last_low = bar.low
 config = {
     "runtime":"DEBUG",
-    "run_type":"LIVE_TRADING",
+    "run_type":"PAPER_TRADING",
     "log":{
             'level':'INFO',
             'file' :r"D:\logs\test\strategy.log",
@@ -116,16 +136,16 @@ config = {
     #        "type":"websocket",
     #        "address":"ws://localhost:14002/"
     #    },
-    #"acct_info":{
-    #        "strategy_id":"21",
-    #        "account":"10030"
-    #    }
     "acct_info":{
-            "strategy_id":"1021",
-            "account":"060031",
-            "password":"Wx@123456",
-            "comp_counter": 96,
-            "broker_type":152
+            "strategy_id":"21",
+            "account":"10030"
         }
+    #"acct_info":{
+    #        "strategy_id":"1021",
+    #        "account":"060031",
+    #        "password":"Wx@123456",
+    #        "comp_counter": 96,
+    #        "broker_type":152
+    #    }
 }
 run_func(**globals())
\ No newline at end of file
