@@ -96,9 +96,10 @@ class WebSocketClient(object):
                  if not self.IsAvaliable():
                      time.sleep(1)
                      continue
-                 result = self.__wsclinet.recv()
+                 msg = self.__wsclinet.recv()
+                 logger.debug("receive msg from:{0},msg:{1}".format(self.config.address,msg))
                  self.__lastActiveTime = datetime.datetime.now()
-                 self.__unhandledQueue.put(result)
+                 self.__unhandledQueue.put(msg)
             except Exception as e:
                 logger.error(self.config.address + 'receive msg exception',e)
                 time.sleep(1)
